@@ -1,10 +1,10 @@
 from .mathtable import MathTable
-from .styles import styledchr, styledstr
-from .zmath import Math, Latex, Text
+from .styles import styledchr
+from .zmath import Math, Latex, Text, reset_numbering
 from .tex import declareoperator
 from .config import config
 
-__version__ = '0.10'
+__version__ = '0.12'
 
 
 declareoperator(r'\tg')
